"""
Wrappers for the "FileProvider" framework on macOS.

These wrappers don't include documentation, please check Apple's documentation
for information on how to use this framework and PyObjC's documentation
for general tips and tricks regarding the translation between Python
and (Objective-)C frameworks
"""
import os

from pyobjc_setup import setup, Extension

VERSION = "9.1.1"

setup(
    name="pyobjc-framework-FileProvider",
    description="Wrappers for the framework FileProvider on macOS",
    min_os_level="10.15",
    packages=["FileProvider"],
    ext_modules=[
        Extension(
            "FileProvider._FileProvider",
            ["Modules/_FileProvider.m"],
            extra_link_args=["-framework", "FileProvider"],
            py_limited_api=True,
            depends=[
                os.path.join("Modules", fn)
                for fn in os.listdir("Modules")
                if fn.startswith("_FileProvider")
            ],
        )
    ],
    version=VERSION,
    install_requires=["pyobjc-core>=" + VERSION, "pyobjc-framework-Cocoa>=" + VERSION],
    long_description=__doc__,
)
